<?php
$translations = array(
	'General_Locale' => 'sk_SK.UTF-8',
	'General_TranslatorName' => 'Miroslav Habara, Zdenko Podobný, Juraj "Lup0" Viktorín',
	'General_TranslatorEmail' => 'miroslav.habara@gmail.com, zdenop@gmail.com, viktorin@automotopneu.sk',
	'General_EnglishLanguageName' => 'Slovak',
	'General_OriginalLanguageName' => 'Slovensky',
	'General_LayoutDirection' => 'ltr',
	'General_HelloUser' => 'Vitaj %s!',
	'General_OpenSourceWebAnalytics' => 'Analýza Webu na báze Open Source',
	'General_Dashboard' => 'Nástenka',
	'General_DashboardForASpecificWebsite' => 'Nástenka pre konkrétnu web stránku',
	'General_MultiSitesSummary' => 'Všetky webstránky',
	'General_AllWebsitesDashboard' => 'Nástenka pre všetky web stránky',
	'General_API' => 'API',
	'General_Widgets' => 'Miniaplikácie',
	'General_Settings' => 'Nastavenia',
	'General_GiveUsYourFeedback' => 'Spätná reakcia!',
	'General_Unknown' => 'Neznáme',
	'General_Never' => 'Nikdy',
	'General_Required' => '%s požadované',
	'General_NotValid' => '%s nie je platné',
	'General_NotDefined' => '%s nie je definované',
	'General_Id' => 'Id',
	'General_Error' => 'Chyba',
	'General_Warning' => 'Varovanie',
	'General_BackToHomepage' => 'Späť na domovskú stránku Piwik',
	'General_Yes' => 'Áno',
	'General_No' => 'Nie',
	'General_Delete' => 'Odstrániť',
	'General_Report' => 'Správa',
	'General_Reports' => 'Správy',
	'General_Edit' => 'Upraviť',
	'General_Download' => 'Stiahnuť',
	'General_Upload' => 'Nahrať',
	'General_Ok' => 'Ok',
	'General_Close' => 'Zatvoriť',
	'General_OrCancel' => 'alebo %s Zatvoriť %s',
	'General_Logout' => 'Odhlásiť',
	'General_Username' => 'Používateľské meno',
	'General_Description' => 'Popis',
	'General_Done' => 'Hotovo',
	'General_PoweredBy' => 'Beží na',
	'General_Name' => 'Meno',
	'General_Value' => 'Hodnota',
	'General_Total' => 'Spolu',
	'General_AverageOrderValue' => 'Prierná hodnota nákupu',
	'General_PurchasedProducts' => 'Nakúpené produkty',
	'General_EcommerceOrders' => 'Ecommerce objednávky',
	'General_AbandonedCarts' => 'Opustené košíky',
	'General_TotalRevenue' => 'Celkový príjem',
	'General_ProductRevenue' => 'Príjem z produktu',
	'General_AveragePrice' => 'Priemerná cena',
	'General_AverageQuantity' => 'Priemerné množstvo',
	'General_UniquePurchases' => 'Unikátne nákupy',
	'General_ProductConversionRate' => 'Konverzná miera produktu',
	'General_Quantity' => 'Množstvo',
	'General_Price' => 'Cena',
	'General_Subtotal' => 'Medzisúčet',
	'General_Tax' => 'Daň',
	'General_Shipping' => 'Doprava',
	'General_Discount' => 'Zľava',
	'General_Details' => 'Detail',
	'General_Default' => 'Základné nastavenie',
	'General_Visit' => 'Návšteva',
	'General_FromReferrer' => 'z',
	'General_VisitorIP' => 'IP návštevníka',
	'General_VisitorID' => 'ID návštevníka',
	'General_VisitType' => 'Typ návštevníka',
	'General_VisitTypeExample' => 'Napríklad: Pre výber všetkých návštevníkov, ktorí sa vrátili na webovú stránku, vrátane tých, ktorí niečo nakúpili počas prechádzajúcej návštevy by API požiadavka obsahovala %s',
	'General_DaysSinceLastVisit' => 'Dní od poslednej návštevy',
	'General_DaysSinceFirstVisit' => 'Dní od prvej návštevy',
	'General_DaysSinceLastEcommerceOrder' => 'Dní od poslednej ecommerce objednávky',
	'General_NumberOfVisits' => 'Počet návštev',
	'General_VisitConvertedGoal' => 'Návšteva dokončila aspoň jeden cieľ',
	'General_VisitConvertedGoalId' => 'Návšteva dokončila špecifické ID cieľu',
	'General_VisitConvertedNGoals' => 'Návšteva dokončila %s cieľov',
	'General_NewVisitor' => 'Nový návštevník',
	'General_NewVisits' => 'Nové návštevy',
	'General_ReturningVisitor' => 'Vracajúci sa návštevník',
	'General_Visitor' => 'Návštevník',
	'General_Date' => 'Dátum',
	'General_Period' => 'Obdobie',
	'General_ChooseDate' => 'Vybrať dátum',
	'General_Today' => 'Dnes',
	'General_Yesterday' => 'Včera',
	'General_CurrentWeek' => 'Aktuálny týždeň',
	'General_CurrentMonth' => 'Aktuálny mesiac',
	'General_CurrentYear' => 'Aktuálny rok',
	'General_DateRange' => 'Časové obdobie:',
	'General_DateRangeInPeriodList' => 'Časové obdobie',
	'General_DateRangeFromTo' => 'Od %s do %s',
	'General_ApplyDateRange' => 'Použiť časový rozsah',
	'General_InvalidDateRange_js' => 'Neplatný cašový rozsah, skúste prosím ešte raz',
	'General_DateRangeFrom_js' => 'Od',
	'General_DateRangeTo_js' => 'Do',
	'General_PreviousDays' => 'Predchádzajúcich %s dní (neobsahuje dnešný deň)',
	'General_LastDays' => 'Posledných %s dní (vrátane dnešného dňa)',
	'General_LoadingData' => 'Načítavanie dát…',
	'General_Loading_js' => 'Načítavanie…',
	'General_GoTo' => 'Prejsť na %s',
	'General_Next' => 'Ďalej',
	'General_Previous' => 'Späť',
	'General_First' => 'Začiatok',
	'General_Search' => 'Hľadanie',
	'General_Others' => 'Ostatné',
	'General_Table' => 'Tabuľka',
	'General_Piechart' => 'Koláčový graf',
	'General_TagCloud' => 'Oblak značiek',
	'General_VBarGraph' => 'Vertikálny stĺpcový graf',
	'General_View' => 'Zobrazenie',
	'General_OpenInNewWindow_js' => 'Otvoriť v novom okne',
	'General_SaveImageOnYourComputer_js' => 'Ak chcete uložiť obrázok na vašom počítači, kliknite pravým tlačidlom na obrázok a vyberte "Uložiť obrázok ako ..."',
	'General_Refresh' => 'Aktualizovať stránku',
	'General_Visitors' => 'Návštevníci',
	'General_ExportThisReport' => 'Exportovať tento dátový súbor v iných formátoch',
	'General_ExportAsImage_js' => 'Exportovať ako obrázok',
	'General_Export' => 'Export',
	'General_ParameterMustIntegerBetween' => 'Parameter %s musí byť číselná hodnota medzi %s a %s.',
	'General_YourChangesHaveBeenSaved' => 'Vaše zmeny boli uložené.',
	'General_ErrorRequest' => 'Oops… problém počas požiadavky, prosím skúste znova.',
	'General_ColumnNbUniqVisitors' => 'Unikátny návštevníci',
	'General_ColumnNbUniqVisitorsDocumentation' => 'Počet neduplikovaných návštevníkov na vašu webovú stránku. Každý návštevník sa počíta len raz, aj keď stránku navštívi niekoľko ráz za deň.',
	'General_ColumnNbVisits' => 'Návštevy',
	'General_ColumnNbVisitsDocumentation' => 'Ak návšteník príde na vašu webovú stránku prvý krát alebo ak navštívi stránku viac ako 30 minút po poslednej impresii, tak sa to bude počítať ako nová návšteva.',
	'General_ColumnPercentageVisits' => '% Návštevy',
	'General_ColumnNbActions' => 'Akcie',
	'General_ColumnNbActionsDocumentation' => 'Počet akcií vykonaných návštevníkmi. Akcie môžu byť zhliadnuté stránky, stiahnutia alebo odchádzajúce prekliky.',
	'General_NbActions' => 'Počet akcií',
	'General_ColumnMaxActions' => 'Maximum akcií počas jednej návštevy',
	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštevníkmi (v sekundách)',
	'General_ColumnLabel' => 'Popis',
	'General_ColumnConversionRate' => 'Miera konverzie',
	'General_ColumnConversionRateDocumentation' => 'Percento náštev spúšťajúcich konverziu cieľa',
	'General_ColumnActionsPerVisit' => 'Akcií na návštevu',
	'General_ColumnActionsPerVisitDocumentation' => 'Priemerná hodnota akcií (zhliadnuté stránky, stiahnutia alebo ochádzajúce prekliky) uskutočnených počas návštev.',
	'General_VisitDuration' => 'Priem. dĺžka návštevy (v sekundách)',
	'General_ColumnAvgTimeOnSite' => 'Priem. čas na webovom sídle',
	'General_ColumnAvgTimeOnSiteDocumentation' => 'Priemerná dĺžka návštevy',
	'General_ColumnVisitDuration' => 'Dĺžka návštevy (v sekundách)',
	'General_ColumnBounceRate' => 'Miera odchodov',
	'General_ColumnBounceRateDocumentation' => 'Percento návštev len s jednou zobrazenou stránkou. To znamená, že návštevník opustil webové sídlo hneď zo vstupnej stránky.',
	'General_ColumnBounceRateForPageDocumentation' => 'Percento návštev so začiatkom aj koncom na tejto stránke.',
	'General_ColumnPageBounceRateDocumentation' => 'Percento návštev, ktoré začali na tejto stránke a potom priamo z webového sídla odišli.',
	'General_ColumnExitRate' => 'Miera opustení',
	'General_ColumnExitRateDocumentation' => 'Percento návštev, ktoré opustili webové sídlo po zhliadnutí tejto stránky.',
	'General_ColumnPageviews' => 'Zobrazené stránky',
	'General_ColumnPageviewsDocumentation' => 'Počet návštev stránky',
	'General_ColumnUniquePageviews' => 'Unikátne zobrazenia stránok',
	'General_ColumnUniquePageviewsDocumentation' => 'Počet návštev zarhnutých do stránky. Viacnásobné zobrazenie stránky počas jednej návštevy sa počíta len raz.',
	'General_ColumnBounces' => 'Odchody',
	'General_ColumnBouncesDocumentation' => 'Počet návštev so začiatkom aj koncom na tejto stránke. To znamená, že návštevník opustil webové sídlo hneď po zhliadnutí tejto jednej stránky.',
	'General_ColumnUniqueEntrances' => 'Unikátnych vstupov',
	'General_ColumnEntrances' => 'Vstupy',
	'General_ColumnEntrancesDocumentation' => 'Počet návštev so začiatkom na tejto stránke.',
	'General_ColumnExits' => 'Odchody',
	'General_ColumnUniqueExits' => 'Unikátne odchody',
	'General_ColumnExitsDocumentation' => 'Počet návštev s koncom na tejto stránke.',
	'General_ColumnAverageTimeOnPage' => 'Priem. doba na stránke',
	'General_ColumnAverageTimeOnPageDocumentation' => 'Priemerný čas, ktorý návštevník strávil na tejto stránke (len na nej, nie na celom webovom sídle).',
	'General_ColumnValuePerVisit' => 'Hodnota na návštevu',
	'General_ColumnVisitsWithConversions' => 'Návštevy s konverziou',
	'General_VisitsWith' => 'Návštevy s %s',
	'General_YearsDays' => '%1$s rokov %2$s dní',
	'General_DaysHours' => '%1$s dní %2$s hodín',
	'General_HoursMinutes' => '%1$s hodín %2$s minút',
	'General_MinutesSeconds' => '%1$s minút %2$s sekúnd',
	'General_Seconds' => '%s sekúnd',
	'General_Save' => 'Uložiť',
	'General_ForExampleShort' => 'napr.',
	'General_YouMustBeLoggedIn' => 'Musíte byť prihlásený pre prístup k tejto functionnality.',
	'General_Website' => 'Webové sídlo',
	'General_GeneralSettings' => 'Všeobecné nastavenia',
	'General_AllowPiwikArchivingToTriggerBrowser' => 'Povoliť Piwiku spustenie archivácií, keď sa reporty zobrazujú z prehliadača',
	'General_ArchivingInlineHelp' => 'Pre stredné až vysoké návštevnosti webových stránok, sa odporúča vypnúť v Piwiku archiváciu spúštanú prezeraním z  prehliadača. Namiesto toho odporúčame nastaviť cron práce na spracovanie Piwik správy každú hodinu.',
	'General_ArchivingTriggerDescription' => 'Odporúča sa pre väčšie inštalácie Piwiku, musíte %s nastavit cron %s aby spracovával správy automaticky.',
	'General_SeeTheOfficialDocumentationForMoreInformation' => 'Pre viac informácií pozri %sofficiálne dokumentácie%s.',
	'General_ReportsContainingTodayWillBeProcessedAtMostEvery' => 'Správy na dnes (alebo iný časový rozsah vrátane dnešného dňa) budú spracované najviac v intervale',
	'General_NSeconds' => '%s sekúnd',
	'General_SmallTrafficYouCanLeaveDefault' => 'Pri malej návštevnosti webového sídla, môžete ponechať predvolený počet sekúnd %s, a prístup do všetkých správ v reálnom čase.',
	'General_MediumToHighTrafficItIsRecommendedTo' => 'Pre webové sídla, ktoré majú stredne veľkú až veľkú návštevnosť, odporúčame pre spracovanie štatistík nastavenie v daný deň maximálne na každú každú pol hodinu (%s sekúnd), alebo každú hodinu (%s sekúnd).',
	'General_RequiresFlash' => 'Zobrazenie grafu vyžaduje Flash',
	'General_GraphHelp' => 'Ďalšie informácie o zobrazení grafov.',
	'General_NoDataForTagCloud' => 'Pre tento oblak nie sú dáta.',
	'General_DisplaySimpleTable' => 'Zobrazenie jednoduchej tabuľky',
	'General_DisplayTableWithMoreMetrics' => 'Zobraziť tabuľku s viacerými metrikami',
	'General_DisplayTableWithGoalMetrics' => 'Zobraziť tabuľku s cieľmi metrík',
	'General_YouAreViewingDemoShortMessage' => 'Momentálne vidíte demo Piwiku',
	'General_DownloadFullVersion' => '%1$sStiahnuť%2$s plnú verziu! Pozri %3$s',
	'General_NewUpdatePiwikX' => 'Nová aktualizácia: Piwik %s',
	'General_AboutPiwikX' => 'O Piwiku %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %1$s je k dispozícií. %2$s Prosím vykonajte aktualizáciu!%3$s (pozrieť %4$s zmeny%5$s).',
	'General_PiwikXIsAvailablePleaseNotifyPiwikAdmin' => '%s je k dispozícii. Notifikujte, prosím, administrátora webu.',
	'General_NewReportsWillBeProcessedByCron' => 'Ak nie je archivovanie Piwiku spúštané prehliadačom, nové správy budú spracované crontabom.',
	'General_ReportsWillBeProcessedAtMostEveryHour' => 'Správy budú budú preto spracované nanajvýš každú hodinu.',
	'General_IfArchivingIsFastYouCanSetupCronRunMoreOften' => 'Za predpokladu, že archivovanie je vo vašom prostredí rýchle, môžete crontab nastaviť na vyššie frekvencie.',
	'General_BackToPiwik' => 'Späť na Piwik',
	'General_ClickHere' => 'Klinite pre viac informácií.',
	'General_ShortMonth_1' => 'Jan',
	'General_ShortMonth_2' => 'Feb',
	'General_ShortMonth_3' => 'Mar',
	'General_ShortMonth_4' => 'Apr',
	'General_ShortMonth_5' => 'Máj',
	'General_ShortMonth_6' => 'Jún',
	'General_ShortMonth_7' => 'Júl',
	'General_ShortMonth_8' => 'Aug',
	'General_ShortMonth_9' => 'Sep',
	'General_ShortMonth_10' => 'Okt',
	'General_ShortMonth_11' => 'Nov',
	'General_ShortMonth_12' => 'Dec',
	'General_LongMonth_1' => 'Január',
	'General_LongMonth_2' => 'Február',
	'General_LongMonth_3' => 'Marec',
	'General_LongMonth_4' => 'Apríl',
	'General_LongMonth_5' => 'Máj',
	'General_LongMonth_6' => 'Jún',
	'General_LongMonth_7' => 'Júl',
	'General_LongMonth_8' => 'August',
	'General_LongMonth_9' => 'September',
	'General_LongMonth_10' => 'Október',
	'General_LongMonth_11' => 'November',
	'General_LongMonth_12' => 'December',
	'General_ShortDay_1' => 'Pon',
	'General_ShortDay_2' => 'Uto',
	'General_ShortDay_3' => 'Str',
	'General_ShortDay_4' => 'Štv',
	'General_ShortDay_5' => 'Pia',
	'General_ShortDay_6' => 'Sob',
	'General_ShortDay_7' => 'Ned',
	'General_LongDay_1' => 'Pondelok',
	'General_LongDay_2' => 'Utorok',
	'General_LongDay_3' => 'Streda',
	'General_LongDay_4' => 'Štvrtok',
	'General_LongDay_5' => 'Piatok',
	'General_LongDay_6' => 'Sobota',
	'General_LongDay_7' => 'Nedeľa',
	'General_Daily' => 'Denne',
	'General_Weekly' => 'Týždenne',
	'General_Monthly' => 'Mesačne',
	'General_ConfigFileIsNotWritable' => 'Konfiguračný súbor %s Piwiku , some of your changes might not be saved. %s Please change permissions of the config file to make it writable.',
	'General_ExceptionDatabaseVersion' => 'Vaša verzia %1$s je %2$s,ale Piwik potrebuje aspoň verziu %3$s.',
	'General_ExceptionIncompatibleClientServerVersions' => 'Vaša verzia klienta %1$s je %2$s je nekompatibilná s verziou servera %3$s.',
	'General_ExceptionMissingFile' => 'Chýba súbor: %s',
	'General_ExceptionFilesizeMismatch' => 'Nesedí veľkosť súboru: %1$s (očakávaná veľkosť: %2$s, nájdená veľkosť: %3$s)',
	'General_ExceptionFileIntegrity' => 'Kontrola integrity sa nepodarila: %s',
	'General_ExceptionNonceMismatch' => 'Nepodarilo sa overiť bezpečnostný reťazec formulára.',
	'General_PleaseSpecifyValue' => 'Špecifikujte, prosím, hodnotu pre %s.',
	'General_ExceptionMethodNotFound' => 'Metóda \'%s\' neexistuje alebo nie je dostupná v module \'%s\'.',
	'General_ExceptionInvalidRendererFormat' => 'Formát vykresľovania \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
	'General_ExceptionInvalidReportRendererFormat' => 'Formát správ \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
	'General_ExceptionInvalidAggregateReportsFormat' => 'Formát agregorvaných správ \'%s\' je neplatný. Skúste namiesto toho použiť jeden z týchto: %s.',
	'General_ExceptionInvalidPeriod' => 'Rozsah \'%s\' nie je podporovaný. Skúste namiesto toho použiť jeden z týchto: %s.',
	'General_ExceptionInvalidDateRange' => 'Dátum \'%s\' nie je platný časový rozsah. Použite nasledovný formát: %s.',
	'General_ExceptionGoalNotFound' => 'ID cieľa = %s  sa nepodarilo nájsť.',
	'General_ExceptionUndeletableFile' => 'Nemožno zmazať %s',
	'General_ExceptionPrivilege' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s".',
	'General_ExceptionPrivilegeAtLeastOneWebsite' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s" aspoň pre jedno webové sídlo.',
	'General_ExceptionPrivilegeAccessWebsite' => 'Nemôžete pristupovať k tomuto zdroju, keďže vyžaduje úroveň prístupu "%s" pre webové sídlo id = %d.',
	'General_ExceptionInvalidArchiveTimeToLive' => 'Dnešný čas archivovania',
	'General_ExceptionConfigurationFileNotFound' => 'Konfiguračný súbor{%s} nebol nájdený.',
	'General_ExceptionUnreadableFileDisabledMethod' => 'Konfiguračný súbor {%s} sa nedá čítať. Váš hostiteľ môže byť poskodený %s.',
	'General_ExceptionInvalidToken' => 'Bezpečnostný reťazec (token) nie je platný.',
	'General_ExceptionInvalidDateFormat' => 'Formát dátumu musí byť: %s alebo kľúčového slova ktoré podporuje funkciu %s (pozri %s pre viac informácií)',
	'General_ExceptionLanguageFileNotFound' => 'Jazykový súbor \'%s\' nebol nájdený.',
	'General_ExceptionUnableToStartSession' => 'Nepodarilo sa začať session.',
	'General_WarningFileIntegritySkipped' => 'Vývojové prostredie detekované. Súbor kontrola integrity preskočený.',
	'General_WarningFileIntegrityNoManifest' => 'Súbor kontrola integrity nemohla byť vykonaná z dôvodu chýbajúcich manifest.inc.php.',
	'General_WarningFileIntegrityNoMd5file' => 'Súbor kontrola integrity nemožno dokončiť z dôvodu chýbajúcich md5_file () funkcie.',
	'General_FileIntegrityWarningExplanation' => 'Súbor kontrola integrity zlyhal a vykazuje nejaké chyby. To je najviac pravdepodobné kvôli čiastočnému nahratiu alebo sa nepodarilo nahrať niektoré zo súborov Piwik. Mali by ste reupload všetky súbory v binárnom móde a obnovte túto stránku, kým nebude vykazovať žiadne chyby.',
	'General_UseSMTPServerForEmail' => 'Použiť SMTP server pre e-mail',
	'General_SmtpServerAddress' => 'Adresa SMTP servera',
	'General_SmtpPort' => 'Metóda overovania pre SMTP',
	'General_AuthenticationMethodSmtp' => 'Metóda overovania pre SMTP',
	'General_SmtpUsername' => 'SMTP používateľské meno',
	'General_SmtpPassword' => 'SMTP heslo',
	'General_SmtpEncryption' => 'SMTP šifrovanie',
	'General_SelectYesIfYouWantToSendEmailsViaServer' => 'Vyberte "Áno", ak chcete alebo musíte odoslať e-mail cez názov servera namiesto lokálnej mail funkcie',
	'General_OptionalSmtpPort' => 'Nepovinné. Východiskové nastavenie je port 25 pre nešifrované spojenie a TLS STMP, či port 465 pre SSL STMP.',
	'General_OnlyUsedIfUserPwdIsSet' => 'Používa sa používateľské meno/heslo ak je nastavené, opýtajte sa svojho poskytovateľa, ak si nie ste istí, ktorú metódu použiť.',
	'General_OnlyEnterIfRequired' => 'Ak to Váš SMTP server vyžaduje zadajte meno',
	'General_OnlyEnterIfRequiredPassword' => 'Ak to Váš SMTP server vyžaduje zadajte heslo',
	'General_WarningPasswordStored' => '%sVarovanie:%s Toto heslo bude uložené v konfiguračnom súbore viditeľné pre všetkých, ako prístup.',
	'General_EncryptedSmtpTransport' => 'Zadajte šifrovanie prenosnej vrstvy požadovanej vašim SMTP serverom.',
	'General_InvalidResponse' => 'Prijaté dáta sú neplatné.',
	'General_ChooseLanguage' => 'Vyberte jazyk',
	'General_ChoosePeriod' => 'Vyberte si obdobie',
	'General_ChooseWebsite' => 'Vyberte si internetové stránky',
	'General_Language' => 'Jazyk',
	'General_PleaseUpdatePiwik' => 'Prosím aktualizujte svoj Piwik',
	'General_RequestTimedOut' => 'Čas %sS vypršal. Prosím skúste to znova.',
	'General_UsePlusMinusIconsDocumentation' => 'Pre navigáciu použite symboly plus a mínus vľavo.',
	'General_BrokenDownReportDocumentation' => 'Je to rozložené do viacerých správ zobrazených ako čiarové grafy na konci stránky. Grafy môžete zväčšiť kliknutím na správu, ktorú chcete vidieť.',
	'General_ChangeTagCloudView' => 'Všimnite si, že správy môžete vidieť aj iným spôsobom ako  oblak značiek. Použite ovládanie na spodku grafu pre prepínanie zobrazenia.',
	'General_Recommended' => '(doporučené)',
	'General_Goal' => 'Cieľ',
	'General_Outlink' => 'Odchádzajúci preklik',
	'General_Help' => 'Pomoc',
	'General_DailySum' => 'Denný súčet',
	'General_AfterEntry' => 'po zadaní sem',
	'General_Metadata' => 'Meta údaje',
	'General_OneVisit' => '1 návšteva',
	'General_NVisits' => '%s návštev',
	'General_OneDay' => '1 deň',
	'General_NDays' => '%s dní',
	'General_MainMetrics' => 'Hlavné metriky',
	'Actions_PluginDescription' => 'Správy o zobrazenie stránky, odkazy a súbory na prevzatie.    Odkazy a súbory na prevzatie sa sledujú automaticky!',
	'Actions_Actions' => 'Akcie',
	'Actions_SubmenuPages' => 'Stránky',
	'Actions_SubmenuPagesEntry' => 'Vstupné stránky',
	'Actions_SubmenuPagesExit' => 'Výstupné stránky',
	'Actions_ExitPageTitles' => 'Titulky výstupnej stránky',
	'Actions_SubmenuPageTitles' => 'Názov stránky',
	'Actions_PageUrls' => 'URL stránok',
	'Actions_SubmenuOutlinks' => 'Externé stránky',
	'Actions_SubmenuDownloads' => 'Sťahovania',
	'Actions_ColumnClicks' => 'Kliknutia',
	'Actions_ColumnClicksDocumentation' => 'Počet kliknutí na odkaz.',
	'Actions_ColumnUniqueClicks' => 'Jedinečné kliknutia',
	'Actions_ColumnDownloads' => 'Sťahovania',
	'Actions_ColumnUniqueDownloads' => 'Jedinečné sťahovania',
	'Actions_ColumnOutlinks' => 'Konkajšie odkazy',
	'Actions_ColumnUniqueOutlinks' => 'Unikátne vonkajšie odkazy',
	'Actions_ColumnPageName' => 'Názov stránky',
	'Actions_ColumnPageURL' => 'Adresa stránky',
	'Actions_ColumnSearchKeyword' => 'Kľúčové slovo',
	'Actions_ColumnClickedURL' => 'Kliknutí na odkaz',
	'Actions_ColumnDownloadURL' => 'Stiahnuté URL',
	'Actions_ColumnEntryPageURL' => 'URL vstupnej stránky',
	'Actions_ColumnEntryPageTitle' => 'Titulok vstupnej stránky',
	'Actions_ColumnExitPageURL' => 'URL výstupnej stránky',
	'Actions_ColumnExitPageTitle' => 'Titulok výstupnej stránky',
	'Actions_ColumnSearches' => 'Vyhľadávania',
	'AnonymizeIP_PluginDescription' => 'Anonymnosť posledný bajt IP adresy návštevníkov v súlade s miestnymi zákonmi na ochranu súkromia.',
	'API_QuickDocumentationTitle' => 'Rýchla dokumentácia k API',
	'API_UserAuthentication' => 'Overenie užívateľa',
	'API_LoadedAPIs' => 'Úspešne načítané %s API',
	'CoreAdminHome_PluginDescription' => 'Správa oblasti Piwik.',
	'CoreAdminHome_MenuGeneralSettings' => 'Všeobecné nastavenie',
	'CoreAdminHome_Administration' => 'Administrácia',
	'CoreAdminHome_UseCustomLogo' => 'Použiť vlastné logo',
	'CoreAdminHome_LogoUpload' => 'Vyberte logo pre načítanie',
	'CoreHome_PluginDescription' => 'Web Analytik report štruktúra.',
	'CoreHome_WebAnalyticsReports' => 'Web Analytik report',
	'CoreHome_ThereIsNoDataForThisReport' => 'Neexistujú žiadne dáta pre túto správu.',
	'CoreHome_CategoryNoData' => 'Pre túto kategóriu nie sú dáta. Skúste použiť „Vrátane celej populácie“.',
	'CoreHome_ShowJSCode' => 'Zobraziť javascript kód pre vloženie',
	'CoreHome_Default_js' => 'Prednastavené',
	'CoreHome_PageOf_js' => '%1$s z %2$s',
	'CoreHome_PeriodDay' => 'Deň',
	'CoreHome_PeriodWeek' => 'Týždeň',
	'CoreHome_PeriodMonth' => 'Mesiac',
	'CoreHome_PeriodYear' => 'Rok',
	'CoreHome_PeriodRange' => 'Rozsah',
	'CoreHome_PeriodDays' => 'dni',
	'CoreHome_PeriodWeeks' => 'týždne',
	'CoreHome_PeriodMonths' => 'mesiace',
	'CoreHome_PeriodYears' => 'roky',
	'General_DaySu_js' => 'Ne',
	'General_DayMo_js' => 'Po',
	'General_DayTu_js' => 'Ut',
	'General_DayWe_js' => 'St',
	'General_DayTh_js' => 'Št',
	'General_DayFr_js' => 'Pi',
	'General_DaySa_js' => 'So',
	'General_ShortDay_1_js' => 'Ne',
	'General_ShortDay_2_js' => 'Po',
	'General_ShortDay_3_js' => 'Ut',
	'General_ShortDay_4_js' => 'St',
	'General_ShortDay_5_js' => 'Št',
	'General_ShortDay_6_js' => 'Pia',
	'General_ShortDay_7_js' => 'So',
	'General_LongDay_1_js' => 'Nedeľa',
	'General_LongDay_2_js' => 'Pondelok',
	'General_LongDay_3_js' => 'Utorok',
	'General_LongDay_4_js' => 'Streda',
	'General_LongDay_5_js' => 'Štvrtok',
	'General_LongDay_6_js' => 'Piatok',
	'General_LongDay_7_js' => 'Sobota',
	'General_ShortMonth_1_js' => 'Jan',
	'General_ShortMonth_2_js' => 'Feb',
	'General_ShortMonth_3_js' => 'Mar',
	'General_ShortMonth_4_js' => 'Apr',
	'General_ShortMonth_5_js' => 'Máj',
	'General_ShortMonth_6_js' => 'Jún',
	'General_ShortMonth_7_js' => 'Júl',
	'General_ShortMonth_8_js' => 'Aug',
	'General_ShortMonth_9_js' => 'Sep',
	'General_ShortMonth_10_js' => 'Okt',
	'General_ShortMonth_11_js' => 'Nov',
	'General_ShortMonth_12_js' => 'Dec',
	'General_MonthJanuary_js' => 'Január',
	'General_MonthFebruary_js' => 'Február',
	'General_MonthMarch_js' => 'Marec',
	'General_MonthApril_js' => 'Apríl',
	'General_MonthMay_js' => 'Máj',
	'General_MonthJune_js' => 'Jún',
	'General_MonthJuly_js' => 'Júl',
	'General_MonthAugust_js' => 'August',
	'General_MonthSeptember_js' => 'September',
	'General_MonthOctober_js' => 'Október',
	'General_MonthNovember_js' => 'November',
	'General_MonthDecember_js' => 'December',
	'CoreHome_ReportGeneratedOn' => 'Report vygenerovaný %s',
	'CoreHome_ReportGeneratedXAgo' => 'Report vygenerovaný pred %s',
	'General_LoadingPopover_js' => 'Načítavanie %s...',
	'CorePluginsAdmin_PluginDescription' => 'Pluginy v administračnom rozhraní.',
	'CorePluginsAdmin_Plugins' => 'Zásuvné moduly',
	'CorePluginsAdmin_PluginsManagement' => 'Správa modulov',
	'CorePluginsAdmin_MainDescription' => 'Moduly rozširujú funkcionalitu projektu Piwik. Po nainštalovaní modulu ho tu môžete aktivovať, alebo deaktivovať.',
	'CorePluginsAdmin_Plugin' => 'Modul',
	'CorePluginsAdmin_Version' => 'Verzia',
	'CorePluginsAdmin_Status' => 'Stav',
	'CorePluginsAdmin_Action' => 'Akcia',
	'CorePluginsAdmin_PluginHomepage' => 'Domovská stránka modulu',
	'CorePluginsAdmin_Activated' => 'Aktivovaný',
	'CorePluginsAdmin_Active' => 'Aktívny',
	'CorePluginsAdmin_Inactive' => 'Neaktívny',
	'CorePluginsAdmin_Deactivate' => 'Deaktivovať',
	'CorePluginsAdmin_Activate' => 'Aktivovať',
	'CorePluginsAdmin_MenuPlugins' => 'Moduly',
	'CoreUpdater_PluginDescription' => 'Piwik aktualizácia mechanizmu',
	'CoreUpdater_UpdateTitle' => 'Piwik › Aktualizácia',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Vyžaduje sa aktualizácia databázy',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Vaša Piwik databáza je zastaralá a musí byť zaktualizovaná, aby ste mohli pokračovať ďalej.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik bude zaktualizovaný z verzie %1$s na verziu %2$s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Nasledujúce moduly budú zaktualizované: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Aktualizácia databázy môžte chvíľu trvať, tak buďte prosím trpezlivý.',
	'CoreUpdater_UpgradePiwik' => 'Aktualizácia Piwik',
	'CoreUpdater_HelpMessageContent' => 'Pozrite si %1$s Piwik FAQ %2$s, kde sú vysvetlené najčastejšie problémy počas aktualizácie. %3$s Požiadajte svojho systémového administrátora - mal by Vám vedieť pomôcť s chybami, ktoré sa s najväčšou pravdepodobnosťou týkajú Vášho servera alebo nastavenia MySQL.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritická chyba počas procesu aktualizácie:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Vyššie je uvedená hlavná chybová správa, ktorá by mala vysvetliť problém. Ak potrebujete ďalšiu pomoc, tak prosím:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Aktualizácia je úspešne ukončená, vyskytli sa však problémy. Prečítajte si nasledovné detaily. Ďalšiu pomoc nájdete na:',
	'CoreUpdater_UpgradeComplete' => 'Aktualizácia je ukončená!',
	'CoreUpdater_WarningMessages' => 'Varovania:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Chyba počas aktualizovania modulov:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Automaticky sa deaktivovali tieto moduly: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik bol úspešne zaktualizovaný!',
	'CoreUpdater_ContinueToPiwik' => 'Pokračovať do projektu Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Automaticky zaktualizovať',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Je dostupná nová verzia Piwik na aktualizáciu',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Môžete aktualizovať na verziu %s automaticky alebo si tiahnuť balíček a vykonať aktualizáciu manuálne:',
	'CoreUpdater_DownloadX' => 'Stiahnuť %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik aktualizácia „jedným kliknutím“ bola zrušená. Ak neviete vyriešiť uvedené chybové hlásenia, odporúčame Vám urobiť aktualizáciu manuálne. %1$s Pred začiatkom sa pozrite sa do %2$sdokumentácie k aktualizácií%3$s!',
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verifikácia rozbalených súborov',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Vytváranie zálohy konfiguračného súboru v %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Inštalácia poslednej verzie',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik bol úspešne zaktualizovaný!',
	'Dashboard_PluginDescription' => 'Váš Web Analytická Nástenka. Môžete si prisp§sobiť Vašu nástenku: Pridať nový nástroj, zmeniť poradie vašich nástrojov. Každý používateľ môže mať prístup k jeho vlastnej nástenke.',
	'Dashboard_Dashboard' => 'Nástenka',
	'Dashboard_DeleteWidgetConfirm' => 'Ste si istý, že chcete odstrániť miniaplikáciu z panela?',
	'Dashboard_SelectWidget' => 'Vyberte miniaplikáciu, ktorá sa pridá na panel',
	'Dashboard_AddPreviewedWidget_js' => 'Pridať prezeranú miniaplikáciu do panelu',
	'Dashboard_WidgetPreview_js' => 'Náhľad na miniaplikáciu',
	'Dashboard_Close_js' => 'Zatvoriť',
	'Dashboard_TitleWidgetInDashboard_js' => 'Miniaplikácia je už na panely',
	'Dashboard_TitleClickToAdd_js' => 'Kliknutím pridáte na panel',
	'Dashboard_LoadingWidget_js' => 'Načítavanie miniaplikácie, prosím čakajte…',
	'Dashboard_WidgetNotFound_js' => 'Miniaplikácia nebola nájdená',
	'DBStats_DatabaseUsage' => 'Využitie databázy',
	'DBStats_MainDescription' => 'Piwik ukladá všetky vaše web analýzy do Mysql databázy. Aktuálne Piwik tabuľky používajú %s.',
	'DBStats_Table' => 'Tabuľka',
	'DBStats_RowCount' => 'Počet riadkov',
	'DBStats_DataSize' => 'Veľkosť dát',
	'DBStats_IndexSize' => 'Veľkosť indexu',
	'DBStats_TotalSize' => 'Celková veľkosť',
	'Goals_Goals' => 'Ciele',
	'Goals_GoalsOverview' => 'Prehľad cieľov',
	'Goals_GoalsManagement' => 'Správa cieľov',
	'Goals_ColumnConversions' => 'Konverzie',
	'Goals_ColumnRevenue' => 'Tržba',
	'Goals_OverallRevenue' => '%s celkové príjmy',
	'Goals_OverallConversionRate' => '%s celková miera konverzie (návštevy s cieľom dokončenia)',
	'Goals_NoGoalsNeedAccess' => 'Len správca alebo Super Užívateľ môže pridať ciele pre dané webové stránky. Prosím, opýtajte sa svojho správcu  ako nastaviť ciele pre vaše webové stránky. <br> sledovanie cieľov je skvelý spôsob, ako pomôcť pochopiť a maximalizovať svoje webové stránky!',
	'Goals_AddNewGoal' => 'Pridať nový cieľ',
	'Goals_AddGoal_js' => 'Pridať ciele',
	'Goals_UpdateGoal_js' => 'Aktualizovať ciele',
	'Goals_DeleteGoalConfirm_js' => 'Ste si istí, že chcete zmazať %s cieľ?',
	'Goals_CreateNewGOal' => 'Vytvoriť nový cieľ',
	'Goals_ViewAndEditGoals' => 'Zobraziť a upraviť ciele',
	'Goals_GoalName' => 'Názov cieľa',
	'Goals_GoalIsTriggered' => 'Cieľ je spustený',
	'Goals_GoalIsTriggeredWhen' => 'Cieľ je spustený keď',
	'Goals_WhenVisitors' => 'návštevníci kedy',
	'Goals_WhereThe' => 'kde',
	'Goals_Manually' => 'ručne',
	'Goals_ManuallyTriggeredUsingJavascriptFunction' => 'Cieľom je ručne spúšťa pomocou JavaScript API trackGoal()',
	'Goals_VisitUrl' => 'Navštívte zadanú URL (stránku alebo skupinu stránok)',
	'Goals_URL' => 'URL',
	'Goals_Filename' => 'názov súboru',
	'Goals_ExternalWebsiteUrl' => 'externá adresa web stránky(URL)',
	'Goals_Download' => 'Stiahnuť súbor',
	'Goals_ClickOutlink' => 'Kliknite na odkaz, na externé webové stránky',
	'Goals_Optional' => '(nepovinné)',
	'Goals_DefaultRevenue' => 'Cieľom predvolené príjmy',
	'Goals_DefaultRevenueHelp' => 'Napríklad, vyplnením a odoslaním cez kontaktný formulár ma návštevník hodnotu 10€. Toto Vám pomôže pochopiť, aký dobre si vedu návštevníci.',
	'Goals_ConversionsOverview' => 'Prehľad konverzií',
	'Goals_BestCountries' => 'Vaša najlepšia konverzia s krajín:',
	'Goals_BestKeywords' => 'Vaše top konverzie kľúčových slov:',
	'Goals_BestReferers' => 'Vaša najlepšia konverzia s webových stránok a odkazovačov:',
	'Goals_ReturningVisitorsConversionRateIs' => 'Miera konverzie vracajúcich sa návštevníkov %s',
	'Goals_NewVisitorsConversionRateIs' => 'Noví návštevníci miera konverzie %s',
	'Goals_Contains' => 'obsahuje %s',
	'Goals_IsExactly' => 'je presne %s',
	'Goals_Pattern' => 'Vzor',
	'Installation_Installation' => 'Inštalácia',
	'Installation_InstallationStatus' => 'Stav inštalácie',
	'Installation_PercentDone' => '%s %% Dokončené',
	'Installation_NoConfigFound' => 'Piwik konfiguračný súbor nie je možné nájsť a vy sa pokúšate pripojiť k Piwik stránke. <br /><b>  » Môžete <a href=\'index.php\'>teraz nainštalovať Piwik</a></b><br /><small>Ak ste nainštalovali Piwik už skôr, a máte nejaké tabuľky s dátami v databáze, nemusíte sa báť, budete ich ďalej používať!</small>',
	'Installation_JsTag' => 'Javascript značka (tag)',
	'Installation_Congratulations' => 'Blahoželanie',
	'Installation_CongratulationsHelp' => '<p>Blahoželáme Vám! Inštalácia Piwik je dokončená.</p><p>Uistite sa, že Váš javascript kód je vložený od Vašich stránok a počkajte si na prvých návštevníkov!</p>',
	'Installation_ContinueToPiwik' => 'Pokračovať do Piwik',
	'Installation_SetupWebsite' => 'Nastavenie webstránky',
	'Installation_SetupWebsiteError' => 'Vyskytla sa chyba pridávaní webstránky',
	'Installation_SuperUserLogin' => 'prihlásenie (login) superpoužívateľa',
	'Installation_Password' => 'heslo',
	'Installation_PasswordRepeat' => 'heslo (zopakovať)',
	'Installation_Email' => 'e-mail',
	'Installation_SecurityNewsletter' => 'posielať informácie o hlavných aktualizáciách projektu Piwik a bezpečnostné varovania',
	'Installation_CommunityNewsletter' => 'posielať informácie o komunitných aktualizáciách (nové moduly, vlastnosti atď.)',
	'Installation_PasswordDoNotMatch' => 'heslo nie je zhodné',
	'Installation_SystemCheck' => 'Kontrola systému',
	'Installation_SystemCheckPhp' => 'PHP verzia',
	'Installation_SystemCheckWriteDirs' => 'Priečinky s prístupom na zápis',
	'Installation_SystemCheckWriteDirsHelp' => 'Na vyriešenie problém v Linuxe skúste napísať nasledovné príkazy',
	'Installation_SystemCheckMemoryLimit' => 'Pamäťový limit',
	'Installation_SystemCheckMemoryLimitHelp' => 'Na webstránkach s vysokou premávkou archivačný proces bude vyžadovať viac pamäte, než je to aktuálne povolené.<br /> Pozrite si direktívu memory_limit vo vašom php.ini súbore, ak je to potrebné.',
	'Installation_SystemCheckGD' => 'GD > 2.x (grafika)',
	'Installation_SystemCheckGDHelp' => '„Sparklines“ (malé grafy) nebudú fungovať.',
	'Installation_SystemCheckTimeLimitHelp' => 'Na webstránkach s vysokou premávkou bude spúšťanie archivačného procesu trvať dlhšie, než je to aktuálne povolené.<br /> Pozrite si direktívu max_execution_time vo vašom php.ini súbore, ak je to potrebné.',
	'Installation_SystemCheckError' => 'Vyskytla sa chyba - musíte ju vyriešiť, inak nie je možné pokračovať',
	'Installation_SystemCheckWarning' => 'Piwik bude fungovať normálne, ale niektoré vlastnosti budú chýbať.',
	'Installation_Tables' => 'Vytváranie tabuliek',
	'Installation_TablesWithSameNamesFound' => 'Niektoré %1$s tabuľky vo vašej databáze %2$s majú rovnaké názvy, ako sa snaží vytvoriť Piwik',
	'Installation_TablesFound' => 'Nasledujúce tabuľky boli nájdené.',
	'Installation_TablesWarningHelp' => 'Vyberte si použitie už existujúcich tabuliek alebo výber čistej inštalácie s vymazaním všetkých existujúcich dát v databáze.',
	'Installation_TablesReuse' => 'Znovu použiť existujúce tabuľky',
	'Installation_TablesDelete' => 'zmazanie delegovaných tabuliek',
	'Installation_TablesDeletedSuccess' => 'Existujúce Piwik tabuľky boli úspešne zmazané',
	'Installation_TablesCreatedSuccess' => 'Tabuľky boli úspešne vytvorené!',
	'Installation_DatabaseCreatedSuccess' => 'Vytvorenie databázy %s prebehlo úspešne!',
	'Installation_GoBackAndDefinePrefix' => 'Choďte späť a zadefinujte predponu pre Piwik tabuľky',
	'Installation_ConfirmDeleteExistingTables' => 'Ste si istý, že chcete zmazať tabuľky: %s z Vašej databázy? VAROVANIE: DÁTA Z TÝCHTO TABULIEK NEBUDE MOŽNÉ OBNOVIŤ!',
	'Installation_Welcome' => 'Vitajte!',
	'Installation_WelcomeHelp' => '<p>Piwik je open source projekt analýzy webstránok, ktorý zjednodušuje získavanie informácií o Vašich návštevníkoch.</p><p>Tento proces je rozdelený do %s jednoduchých krokov a bude trvať asi 5 minút.</p>',
	'Installation_ErrorInvalidState' => 'Chyba: zdá sa, že sa pokúšate preskočiť krok v inštalačnom procese, alebo máte zakázané „cookies“, alebo je Piwik konfiguračný súbor už vytvorený. %1$sUistite sa, že máte povolené „cookies“%2$s a potom choďte späť %3$s na prvú stránku inštalácie %4$s.',
	'Live_PluginDescription' => 'Spy na svojich návštevníkov, naživo, v reálnom čase!',
	'Live_LinkVisitorLog' => 'Zobraziť podrobný záznam návštevníkov',
	'Live_Actions' => 'Akcie',
	'Live_Action' => 'Akcia',
	'Live_VisitorLog' => 'Záznam návštevníka',
	'Live_Time' => 'Čas',
	'Live_Referrer_URL' => 'Referenčné URL',
	'Live_GoalType' => 'Typ',
	'Live_GoalTime' => '1. Prechodné obdobie',
	'Live_GoalRevenue' => 'Príjmy',
	'Live_GoalDetails' => 'Podrobnosti',
	'Login_PluginDescription' => 'Prihlásiť pre overenie pluginu, čítanie poverenia z config / config.inc.php súbor pre super užívateľa, a z databázy pre ostatných užívateľov. Môže byť ľahko nahradený s cieľom vytvoriť nový mechanizmus autentifikácie (OpenID, htaccess, vlastné Auth, atď).',
	'Login_LoginPasswordNotCorrect' => 'Meno používateľa a heslo nie sú správne',
	'Login_Password' => 'Heslo',
	'Login_PasswordRepeat' => 'Heslo (znovu)',
	'Login_ChangePassword' => 'Zmena hesla',
	'Login_LoginOrEmail' => 'Prihlasovací údaj (Login) alebo e-mail',
	'Login_LogIn' => 'Prihlásiť sa',
	'Login_Logout' => 'Odhlásiť sa',
	'Login_LostYourPassword' => 'Zabudli ste heslo?',
	'Login_PasswordsDoNotMatch' => 'Heslá sa nezhodujú.',
	'Login_InvalidUsernameEmail' => 'Neplatné meno používateľa alebo e-mailová adresa',
	'Login_InvalidOrExpiredToken' => 'Token je neplatný, alebo už vypršal.',
	'Login_ContactAdmin' => 'Možné dôvody: Váš server ma zakázanú funkciu mail().<br /> Skontaktujte svojho administrátora Piwik.',
	'Login_ExceptionPasswordMD5HashExpected' => 'Očakávajte že heslo bude v MD5 hash.',
	'Login_ExceptionInvalidSuperUserAuthenticationMethod' => 'Super používateľ nemôže overiť pomocou \'%s\' mechanizmu.',
	'Mobile_AnonymousAccess' => 'Anonymný prístup',
	'Mobile_AccessUrlLabel' => 'Prístup Url',
	'Mobile_EnableGraphsLabel' => 'Zobraziť grafy',
	'MultiSites_PluginDescription' => 'Zobrazuje Multi-Site zhrnutie / štatistiky. V súčasnej dobe je ako hlavný plugin.',
	'MultiSites_Evolution' => 'Vývoj',
	'Provider_PluginDescription' => 'Report cez ktorého poskytovateľa pripojenia prišli návštevníci na web stránku.',
	'Provider_WidgetProviders' => 'Poskytovatelia',
	'Provider_ColumnProvider' => 'Poskytovateľ',
	'Provider_SubmenuLocationsProvider' => 'Umiestnenie & poskytovateľ',
	'Referers_PluginDescription' => 'Report o odkazoch: Vyhľadávače, Kľúčové slová, webové stránky, monitorovanie kampaní, priamy vstup.',
	'Referers_Referers' => 'Odkazy',
	'Referers_SearchEngines' => 'Vyhľadávače',
	'Referers_Keywords' => 'Kľúčové slová',
	'Referers_DirectEntry' => 'Priamy vstup',
	'Referers_Websites' => 'Webstránky',
	'Referers_Campaigns' => 'Kampane',
	'Referers_Evolution' => 'Vývoj za obdobie',
	'Referers_Type' => 'Typ odkazu',
	'Referers_ColumnRefererType' => 'Typ odkazu',
	'Referers_ColumnSearchEngine' => 'Vyhľadávač',
	'Referers_ColumnWebsite' => 'Portál',
	'Referers_ColumnWebsitePage' => 'Stránka portálu',
	'Referers_ColumnKeyword' => 'Kľúčové slovo',
	'Referers_ColumnCampaign' => 'Kampaň',
	'Referers_DetailsByRefererType' => 'Detaily za typ odkazu',
	'Referers_TypeDirectEntries' => '%s priamych vstupov',
	'Referers_TypeSearchEngines' => '%s z vyhľadávačov',
	'Referers_TypeWebsites' => '%s zo stránok',
	'Referers_TypeCampaigns' => '%s z kampaní',
	'Referers_Distinct' => 'Rozlíšiť odkazy podľa typu odkazu',
	'Referers_DistinctSearchEngines' => 'rôzne vyhľadávače',
	'Referers_DistinctKeywords' => 'rôzne kľúčové strany',
	'Referers_DistinctCampaigns' => 'rôzne kampane',
	'Referers_DistinctWebsites' => 'rôzne portály',
	'Referers_UsingNDistinctUrls' => '(pomocou %s rôznych adries URL)',
	'Referers_SubmenuSearchEngines' => 'Vyhľadávače a kľúčové slová',
	'Referers_SubmenuWebsites' => 'Webstránky',
	'Referers_SubmenuCampaigns' => 'Kampane',
	'Referers_WidgetKeywords' => 'Zoznam kľúčových slov',
	'Referers_WidgetCampaigns' => 'Zoznam Kampaní',
	'Referers_WidgetExternalWebsites' => 'Zoznam externých stránok',
	'Referers_WidgetSearchEngines' => 'Najlepšie vyhľadávače',
	'Referers_WidgetOverview' => 'Prehľad',
	'SEO_SeoRankings' => 'SEO hodnotenie',
	'SEO_AlexaRank' => 'Alexa hodnotenie',
	'SEO_DomainAge' => 'Vek domény',
	'SEO_Rank' => 'Hodnotenie',
	'SEO_Pages' => 'Stránky',
	'SEO_SEORankingsFor' => 'SEO hodnotenie pre %s',
	'SitesManager_Sites' => 'Stránky',
	'SitesManager_WebsitesManagement' => 'Správa webstránok',
	'SitesManager_MainDescription' => 'Váš report analýzy webu potrebuje webstránky! Tu si pridajte, aktualizujte, odstráňte webstránky alebo zobrazte Javascript kód pre vaše stránky.',
	'SitesManager_JsTrackingTag' => 'JavaScript sledovacia značka (tag)',
	'SitesManager_JsTrackingTagHelp' => 'Tu je JavaScript sledovacia značka (tag) na vloženie do vašich stránok',
	'SitesManager_ShowTrackingTag' => 'zobraziť sledovaciu značku',
	'SitesManager_NoWebsites' => 'Nemáte webstránky na administrovanie.',
	'SitesManager_AddSite' => 'Pridať novú stránku',
	'SitesManager_Urls' => 'URL',
	'SitesManager_MenuSites' => 'Stránky',
	'SitesManager_DeleteConfirm_js' => 'Ste si istý, že chcete zmazať webstránku %s?',
	'SitesManager_ExceptionDeleteSite' => 'Nie je možné odstrániť webstránku, pretože je jediná registrovaná webstránka. Najskôr pridajte novú webstránka a potom môžete odstrániť túto.',
	'SitesManager_ExceptionNoUrl' => 'Musíte zadať aspoň jednu URL pre stránku.',
	'SitesManager_ExceptionEmptyName' => 'Názov stránok nemôže byť prázdny.',
	'SitesManager_ExceptionInvalidUrl' => 'Url \'%s\' nie je platná URL.',
	'TranslationsAdmin_MenuTranslations' => 'Preklady',
	'TranslationsAdmin_MenuLanguages' => 'Jazyky',
	'TranslationsAdmin_LanguageCode' => 'Kód jazyka',
	'TranslationsAdmin_Plugin' => 'Modul',
	'TranslationsAdmin_Definition' => 'Definícia',
	'TranslationsAdmin_DefaultString' => 'Štandardný reťazec (Anglicky)',
	'TranslationsAdmin_TranslationString' => 'Preklad (aktuálny jazyk: %s)',
	'TranslationsAdmin_Translations' => 'Preklady',
	'TranslationsAdmin_FixPermissions' => 'Prosím vyriešte problém s nastavením prístupu v súborovom systéme',
	'TranslationsAdmin_AddLanguage' => 'Pridať jazyk',
	'TranslationsAdmin_Export' => 'Exportovať jazyk',
	'TranslationsAdmin_Import' => 'Importovať jazyk',
	'UserCountry_PluginDescription' => 'Report návštevníkov podľa krajiny',
	'UserCountry_Country' => 'Krajina',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_City' => 'Mesto',
	'UserCountry_DistinctCountries' => 'Počet rôznych krajín: %s',
	'UserCountry_Location' => 'Miesto',
	'UserCountry_SubmenuLocations' => 'Umiestnenie',
	'UserCountry_country_ac' => 'Ostrov Ascension',
	'UserCountry_country_ad' => 'Andora',
	'UserCountry_country_ae' => 'Spojené arabské emiráty',
	'UserCountry_country_af' => 'Afganistan',
	'UserCountry_country_ag' => 'Antigua a Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albánsko',
	'UserCountry_country_am' => 'Arménsko',
	'UserCountry_country_an' => 'Holandské Antily',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktída',
	'UserCountry_country_ar' => 'Argentína',
	'UserCountry_country_as' => 'Americká Samoa',
	'UserCountry_country_at' => 'Rakúsko',
	'UserCountry_country_au' => 'Austrália',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Alandy',
	'UserCountry_country_az' => 'Azerbajdžan',
	'UserCountry_country_ba' => 'Bosna a Hercegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladéš',
	'UserCountry_country_be' => 'Belgicko',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulharsko',
	'UserCountry_country_bh' => 'Bahrajn',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthélemy',
	'UserCountry_country_bm' => 'Bermudy',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolívia',
	'UserCountry_country_br' => 'Brazília',
	'UserCountry_country_bs' => 'Bahamy',
	'UserCountry_country_bt' => 'Bhután',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvetov ostrov',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Bielorusko',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kokosové ostrovy',
	'UserCountry_country_cd' => 'Konžská demokratická republika (býv. Zair)',
	'UserCountry_country_cf' => 'Stredoafrická republika',
	'UserCountry_country_cg' => 'Kongo',
	'UserCountry_country_ch' => 'Švajčiarsko',
	'UserCountry_country_ci' => 'Pobrežie Slonoviny',
	'UserCountry_country_ck' => 'Cookove ostrovy',
	'UserCountry_country_cl' => 'Čile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Čína',
	'UserCountry_country_co' => 'Kolumbia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Kostarika',
	'UserCountry_country_cs' => 'Srbsko-Čierna Hora',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Kapverdy',
	'UserCountry_country_cx' => 'Vianočný ostrov',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Česká republika',
	'UserCountry_country_de' => 'Nemecko',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Džibutsko',
	'UserCountry_country_dk' => 'Dánsko',
	'UserCountry_country_dm' => 'Dominika',
	'UserCountry_country_do' => 'Dominikánska republika',
	'UserCountry_country_dz' => 'Alžírsko',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ekvádor',
	'UserCountry_country_ee' => 'Estónsko',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Západná Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Španielsko',
	'UserCountry_country_et' => 'Etiópia',
	'UserCountry_country_eu' => 'Európska Únia',
	'UserCountry_country_fi' => 'Fínsko',
	'UserCountry_country_fj' => 'Fidži',
	'UserCountry_country_fk' => 'Falklandy',
	'UserCountry_country_fm' => 'Mikronézske federatívne štáty',
	'UserCountry_country_fo' => 'Faerské ostrovy',
	'UserCountry_country_fr' => 'Francúzsko',
	'UserCountry_country_fx' => 'Metropolitné Francúzsko',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Veľká Británia',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Gruzínsko',
	'UserCountry_country_gf' => 'Francúzska Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltár',
	'UserCountry_country_gl' => 'Grónsko',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Rovníková Guinea',
	'UserCountry_country_gr' => 'Grécko',
	'UserCountry_country_gs' => 'Južná Georgia a Južné Sandwichove ostrovy',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heardov ostrov',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Chorvátsko',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Maďarsko',
	'UserCountry_country_ic' => 'Kanárske ostrovy',
	'UserCountry_country_id' => 'Indonézia',
	'UserCountry_country_ie' => 'Írsko',
	'UserCountry_country_il' => 'Izrael',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'Britské indickooceánske územie',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iránska islamská republika',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Taliansko',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamajka',
	'UserCountry_country_jo' => 'Jordánsko',
	'UserCountry_country_jp' => 'Japonsko',
	'UserCountry_country_ke' => 'Keňa',
	'UserCountry_country_kg' => 'Kirgizsko',
	'UserCountry_country_kh' => 'Kambodža',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komory',
	'UserCountry_country_kn' => 'Svätý Krištof a Nevis',
	'UserCountry_country_kp' => 'Kórejská ľudovodemokratická republika',
	'UserCountry_country_kr' => 'Kórejská republika',
	'UserCountry_country_kw' => 'Kuvajt',
	'UserCountry_country_ky' => 'Kajmanie ostrovy',
	'UserCountry_country_kz' => 'Kazachstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Svätá Lucia',
	'UserCountry_country_li' => 'Lichtenštajnsko',
	'UserCountry_country_lk' => 'Srí Lanka',
	'UserCountry_country_lr' => 'Libéria',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Litva',
	'UserCountry_country_lu' => 'Luxembursko',
	'UserCountry_country_lv' => 'Lotyšsko',
	'UserCountry_country_ly' => 'Líbya',
	'UserCountry_country_ma' => 'Maroko',
	'UserCountry_country_mc' => 'Monako',
	'UserCountry_country_md' => 'Moldavská republika',
	'UserCountry_country_me' => 'Čierna Hora',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshallove ostrovy',
	'UserCountry_country_mk' => 'Macedónsko',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Mjanmarsko',
	'UserCountry_country_mn' => 'Mongolsko',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Severné Mariány',
	'UserCountry_country_mq' => 'Martinik',
	'UserCountry_country_mr' => 'Mauritánia',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Maurícius',
	'UserCountry_country_mv' => 'Maldivy',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexiko',
	'UserCountry_country_my' => 'Malajzia',
	'UserCountry_country_mz' => 'Mozambik',
	'UserCountry_country_na' => 'Namíbia',
	'UserCountry_country_nc' => 'Nová Kaledónia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk',
	'UserCountry_country_ng' => 'Nigéria',
	'UserCountry_country_ni' => 'Nikaragua',
	'UserCountry_country_nl' => 'Holandsko',
	'UserCountry_country_no' => 'Nórsko',
	'UserCountry_country_np' => 'Nepál',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutrálna zóna',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nový Zéland',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Francúzska Polynézia',
	'UserCountry_country_pg' => 'Papua Nová Guinea',
	'UserCountry_country_ph' => 'Filipíny',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poľsko',
	'UserCountry_country_pm' => 'Saint Pierre a Miquelon',
	'UserCountry_country_pn' => 'Pitcairnove ostrovy',
	'UserCountry_country_pr' => 'Portoriko',
	'UserCountry_country_ps' => 'Palestína',
	'UserCountry_country_pt' => 'Portugalsko',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguaj',
	'UserCountry_country_qa' => 'Katar',
	'UserCountry_country_re' => 'Réunion',
	'UserCountry_country_ro' => 'Rumunsko',
	'UserCountry_country_rs' => 'Srbsko',
	'UserCountry_country_ru' => 'Rusko',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudská Arábia',
	'UserCountry_country_sb' => 'Šalamúnove ostrovy',
	'UserCountry_country_sc' => 'Seychely',
	'UserCountry_country_sd' => 'Sudán',
	'UserCountry_country_se' => 'Švédsko',
	'UserCountry_country_sf' => 'Fínsko',
	'UserCountry_country_sg' => 'Singapur',
	'UserCountry_country_sh' => 'Svätá Helena',
	'UserCountry_country_si' => 'Slovinsko',
	'UserCountry_country_sj' => 'Svalbard Jan Mayen',
	'UserCountry_country_sk' => 'Slovensko',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Maríno',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somálsko',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Svätý Tomáš a Princov ostrov',
	'UserCountry_country_su' => 'Bývalé ZSSR',
	'UserCountry_country_sv' => 'Salvádor',
	'UserCountry_country_sy' => 'Sýria',
	'UserCountry_country_sz' => 'Svazijsko',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks a Caicos',
	'UserCountry_country_td' => 'Čad',
	'UserCountry_country_tf' => 'Francúzske južné územia',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thajsko',
	'UserCountry_country_tj' => 'Tadžikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'Východný Timor',
	'UserCountry_country_tm' => 'Turkménsko',
	'UserCountry_country_tn' => 'Tunis',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'Východný Timor',
	'UserCountry_country_tr' => 'Turecko',
	'UserCountry_country_tt' => 'Trinidad a Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzánijská zjednotená republika',
	'UserCountry_country_ua' => 'Ukrajina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Spojené Kráľovstvo',
	'UserCountry_country_um' => 'Menšie odľahlé ostrovy USA',
	'UserCountry_country_us' => 'Spojené štáty',
	'UserCountry_country_uy' => 'Uruguaj',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikán',
	'UserCountry_country_vc' => 'Svätý Vincent a Grenadíny',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Britské Panenské ostrovy',
	'UserCountry_country_vi' => 'Americké panenské ostrovy',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis a Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Juhoslávia',
	'UserCountry_country_za' => 'Južná Afrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zair',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Európa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Ázia',
	'UserCountry_continent_amn' => 'Severná Amerika',
	'UserCountry_continent_ams' => 'Stredná a Južná Amerika',
	'UserCountry_continent_oce' => 'Oceánia',
	'UserCountryMap_map' => 'mapa',
	'UserCountryMap_worldMap' => 'svetová mapa',
	'UserCountryMap_toggleFullscreen' => 'Prepínač na celú obrazovku',
	'UserSettings_PluginDescription' => 'Rôzne reporty užívateľského nastavenia: Prehliadač, Rodina prehliadača, Operačný systém, Pluginy, Rozlíšenie, Globálne nastavenia.',
	'UserSettings_VisitorSettings' => 'Nastavenia návštevníkov',
	'UserSettings_BrowserFamilies' => 'Rodina prehliadača',
	'UserSettings_Browsers' => 'Prehliadače',
	'UserSettings_Plugins' => 'Zásuvné moduly',
	'UserSettings_Configurations' => 'Konfigurácia',
	'UserSettings_OperatingSystems' => 'Operačný systém',
	'UserSettings_Resolutions' => 'Rozlíšenie',
	'UserSettings_WideScreen' => 'Širokouhlá obrazovka',
	'UserSettings_ColumnBrowserFamily' => 'Rodina prehliadača',
	'UserSettings_ColumnBrowser' => 'Prehliadač',
	'UserSettings_ColumnPlugin' => 'Zásuvný modul',
	'UserSettings_ColumnConfiguration' => 'Konfigurácia',
	'UserSettings_ColumnOperatingSystem' => 'Operačný systém',
	'UserSettings_ColumnResolution' => 'Rozlíšenie',
	'UserSettings_ColumnTypeOfScreen' => 'Typ obrazovky',
	'UserSettings_WidgetResolutions' => 'Rozlíšenie obrazovky',
	'UserSettings_WidgetBrowsers' => 'Prehliadače návštevníkov',
	'UserSettings_WidgetPlugins' => 'Zoznam modulov',
	'UserSettings_PluginDetectionDoesNotWorkInIE' => 'Poznámka: Plugin detekcia nefunguje v Internet Exploreri. Táto správa je založená len na non-IE prehliadačov.',
	'UserSettings_WidgetWidescreen' => 'Bežný/Širokouhlý',
	'UserSettings_WidgetBrowserFamilies' => 'Prehliadače podľa rodiny',
	'UserSettings_WidgetOperatingSystems' => 'Operačné systémy',
	'UserSettings_WidgetGlobalVisitors' => 'Globálne konfigurácie návštevníkov',
	'UserSettings_SubmenuSettings' => 'Nastavenia',
	'UsersManager_UsersManagement' => 'Správa používateľov',
	'UsersManager_UsersManagementMainDescription' => 'Vytvorenie nových alebo aktualizácia existujúcich používateľov V sekcií vyššie im môžete nastaviť rozsah prístupov.',
	'UsersManager_ManageAccess' => 'Správa prístupov',
	'UsersManager_MainDescription' => 'Rozhodnite sa, ktorí používatelia budú môcť pristupovať k jednotlivým stránkam. Tiež im môžete umožniť prístup na všetky vaše stránky.',
	'UsersManager_Sites' => 'Webstránky',
	'UsersManager_AllWebsites' => 'Všetky webstránky',
	'UsersManager_ApplyToAllWebsites' => 'Použiť na všetky webstránky',
	'UsersManager_User' => 'Používatelia',
	'UsersManager_PrivNone' => 'Bez prístupu',
	'UsersManager_PrivView' => 'Prezeranie',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => 'Ste si istý, že chcete zmeniť \'%s\' práva pre všetky webstránky?',
	'UsersManager_Password' => 'Heslo',
	'UsersManager_Email' => 'E-mail',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Edit' => 'Upraviť',
	'UsersManager_AddUser' => 'Pridať nového používateľa',
	'UsersManager_MenuUsers' => 'Používatelia',
	'UsersManager_MenuUserSettings' => 'Užívateľské nastavenia',
	'UsersManager_MenuAnonymousUserSettings' => 'Nastavenie pre anonymného užívateľa',
	'UsersManager_ChangePassword' => 'Zmena hesla',
	'UsersManager_TypeYourPasswordAgain' => 'Zadajte nové heslo znovu.',
	'UsersManager_DeleteConfirm_js' => 'Ste si istý, že chcete odstrániť používateľa %s?',
	'UsersManager_YourUsernameCannotBeChanged' => 'Vaše užívateľské meno sa nedá zmeniť.',
	'UsersManager_ExceptionLoginExists' => 'Používateľ (login) \'%s\' už existuje.',
	'UsersManager_ExceptionEmailExists' => 'Používateľ s e-mailom \'%s\' už existuje.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Počet znakov pre Používateľ (login) musí byť medzi %1$s a %2$s a obsahovať iba písmená, číslice alebo znaky \'_\', \'-\', a \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'E-mailová adresa nemá platný formát.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Používateľ \'%s\' neexistuje a preto nemôže byť odstránený.',
	'UsersManager_ExceptionAdminAnonymous' => 'Nemôžete priradiť prístup \'admin\' pre používateľa \'anonymous\'.',
	'UsersManager_ExceptionEditAnonymous' => 'Anonymný používateľ nemôže byť odstránený alebo upravený. Piwik ho používa na definovanie používateľa, ktorý sa ešte prihlásil. Anonymného používateľa môžete použiť na zverejnenie svojich štatistík, a to priradeným mu práv na prezeranie.',
	'UsersManager_ExceptionSuperUser' => 'Požadovaný používateľ je superpoužívateľ, na ktorého nemôže byť odoslaná požiadavka, nemôže byť upravený alebo zmazaný cez API. Manuálne môžete upraviť detaily superpoužívateľa v Piwik konfiguračnom súbore.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Používateľ \'%s\' neexistuje.',
	'UsersManager_ExceptionAccessValues' => 'Parameter prístupu musí mať jednu z nasledujúcich hodnôt : [ %s ]',
	'VisitFrequency_PluginDescription' => 'Rôzne štatistiky vracajúci sa návštevník versus návštevník ktorý navštívil stránku prvýkrát.',
	'VisitFrequency_Evolution' => 'Vývoj za obdobie',
	'VisitFrequency_ColumnReturningVisits' => 'Vracajúce sa návštevy',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'Akcie vracajúcich sa návštevníkov',
	'VisitFrequency_ColumnAverageVisitDurationForReturningVisitors' => 'Avg. Navštívte Čas pre návštevníkov vracať (v sekundách)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Miera odskočení vracajúcich sa návštev',
	'VisitFrequency_ColumnAvgActionsPerReturningVisit' => 'Priemerný čas pre vracajúcich sa návštevníkov (v sekundách)',
	'VisitFrequency_ReturnVisits' => 'počet vracajúcich sa: %s',
	'VisitFrequency_ReturnActions' => 'počet akcií vracajúcich sa: %s',
	'VisitFrequency_ReturnAvgActions' => '%s akcie pre vracajúcej sa návšteve',
	'VisitFrequency_ReturnAverageVisitDuration' => '%s priemerná dĺžka návštevy u vracajúcich sa návštevníkov',
	'VisitFrequency_ReturnBounceRate' => '%s vracajúcich sa návštev odskočilo (odišli po zobrazení jednej stránky)',
	'VisitFrequency_WidgetOverview' => 'Prehľad frekvencií',
	'VisitFrequency_WidgetGraphReturning' => 'Graf vracajúcich sa',
	'VisitFrequency_SubmenuFrequency' => 'Frekvencia',
	'VisitorGenerator_PluginDescription' => 'Plugin pre vytvorenie falošnej návštevy. Toto môže byť používané užívatelia Analytik nástroja alebo vývojári ako jednoduchý spôsob, ako vytvárať falošné údaje k naplneniu Analytického nástroja správy.',
	'VisitorGenerator_VisitorGenerator' => 'Generátor návštev',
	'VisitorGenerator_Warning' => 'Chystáte sa vytvárať falošné návštev, ktoré budú zaznamenané v databáze.',
	'VisitorGenerator_NotReversible' => 'To bude %s %s možné ľahko odstrániť pre tieto návštevy v záznamoch.',
	'VisitorGenerator_AreYouSure' => 'Ste si istí, že chcete vytvoriť falošné návštevy?',
	'VisitorGenerator_ChoiceYes' => 'Áno, som si istý!',
	'VisitorGenerator_Submit' => 'Odoslať',
	'VisitorGenerator_SelectWebsite' => 'Vybrať web',
	'VisitorGenerator_NbRequestsPerSec' => 'Žiadosti za sekundu',
	'VisitorGenerator_DaysToCompute' => 'Dni pre výpočet',
	'VisitorInterest_PluginDescription' => 'Správy o záujme návštevníkov: počet zobrazených stránok, čas strávený na týchto stránkach.',
	'VisitorInterest_VisitsPerDuration' => 'Návštevy podľa dĺžky trvania návštevy',
	'VisitorInterest_VisitsPerNbOfPages' => 'Návštevy na počet stránok',
	'VisitorInterest_ColumnVisitDuration' => 'Trvanie návštevy',
	'VisitorInterest_ColumnPagesPerVisit' => 'Stránky na návštevu',
	'VisitorInterest_WidgetLengths' => 'Trvanie návštev',
	'VisitorInterest_WidgetPages' => 'Strany na návštevu',
	'VisitorInterest_Engagement' => 'Záujem',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1$s-%2$s min',
	'VisitorInterest_OnePage' => '1 stránka',
	'VisitorInterest_NPages' => '%s stránok',
	'VisitorInterest_BetweenXYSeconds' => '%1$s-%2$ss',
	'VisitsSummary_PluginDescription' => 'Všeobecný analytický report: návštevy, jedinečné návštevy, počet akcií, Bounce Rate, atď',
	'VisitsSummary_VisitsSummary' => 'Všetky návštevy',
	'VisitsSummary_NbVisits' => 'Počet návštev: %s',
	'VisitsSummary_NbUniqueVisitors' => 'Počet unikátnych návštevníkov: %s',
	'VisitsSummary_NbActionsDescription' => '%s akcie (zobrazenie stránok, sťahovanie a odkazujúce odkazy)',
	'VisitsSummary_AverageVisitDuration' => '%s priemerná dĺžka návštevy',
	'VisitsSummary_MaxNbActions' => 'Max. akcií na jednu návštevu: %s',
	'VisitsSummary_NbActionsPerVisit' => '%s akcia za návštevu',
	'VisitsSummary_NbVisitsBounced' => '%s návštev odskočilo (odišli po zobrazení jednej stránky)',
	'VisitsSummary_GenerateTime' => '%s sekúnd na vygenerovanie strany',
	'VisitsSummary_GenerateQueries' => 'spustené požiadavky: %s',
	'VisitsSummary_WidgetLastVisits' => 'Graf posledných návštev',
	'VisitsSummary_WidgetVisits' => 'Prehľad návštevníkov',
	'VisitsSummary_WidgetLastVisitors' => 'Graf posledných jedinečných návštevníkov',
	'VisitsSummary_WidgetOverviewGraph' => 'Prehľad s grafom',
	'VisitsSummary_SubmenuOverview' => 'Prehľad',
	'VisitTime_PluginDescription' => 'Report miestneho a serverového času. Serverový čas môže byť užitočný pre plánovanie údržby na internetových stránkach.',
	'VisitTime_LocalTime' => 'Návštevníci podľa lokálneho času',
	'VisitTime_ServerTime' => 'Návštevníci podľa serverového času',
	'VisitTime_ColumnServerTime' => 'Serverový čas',
	'VisitTime_ColumnLocalTime' => 'Miestny čas',
	'VisitTime_WidgetLocalTime' => 'Návštevníci podľa lokálneho času',
	'VisitTime_WidgetServerTime' => 'Návštevníci podľa serverového času',
	'VisitTime_SubmenuTimes' => 'Časy',
	'VisitTime_NHour' => '%sh',
	'Widgetize_PluginDescription' => 'Je veľmi jednoduché vložiť widget na svoj blog, web alebo na stránku iGoogle a Netvibes!',
	'PDFReports_EmailReports' => 'Reporty e-mailom',
	'PDFReports_PDF' => 'PDF',
	'PDFReports_SendReportNow' => 'Teraz poslať report',
	'PDFReports_EmailSchedule' => 'E-mail report',
	'PDFReports_SendReportTo' => 'Poslať report',
	'PDFReports_SentToMe' => 'Pošli na',
	'PDFReports_WeeklyScheduleHelp' => 'Týždenný plán: správa bude odoslaná prvý pondelok každého týždňa.',
	'PDFReports_MonthlyScheduleHelp' => 'Mesačný plán: správa bude odoslaná prvý deň každého mesiaca.',
	'PDFReports_AlsoSendReportToTheseEmails' => 'Tiež poslať správu na tieto e-maily (jeden e-mail na riadok):',
	'PDFReports_PiwikReports' => 'Reporty',
	'PDFReports_EmailHello' => 'Ahoj,',
	'PDFReports_PleaseFindAttachedFile' => 'Nájdete v priloženom súbore %1$s reporte pre %2$s.',
	'UserLanguage_Language_aa' => 'afarčina',
	'UserLanguage_Language_ab' => 'abcházština',
	'UserLanguage_Language_ae' => 'avestčina',
	'UserLanguage_Language_af' => 'afrikánčina',
	'UserLanguage_Language_ak' => 'akančina',
	'UserLanguage_Language_am' => 'amharčina',
	'UserLanguage_Language_an' => 'aragónčina',
	'UserLanguage_Language_ar' => 'arabčina',
	'UserLanguage_Language_as' => 'ásámčina',
	'UserLanguage_Language_av' => 'avarčina',
	'UserLanguage_Language_ay' => 'aymarčina',
	'UserLanguage_Language_az' => 'azerbajdžančina',
	'UserLanguage_Language_ba' => 'baskirčina',
	'UserLanguage_Language_be' => 'bieloruština',
	'UserLanguage_Language_bg' => 'bulharčina',
	'UserLanguage_Language_bh' => 'bihárske jazyky',
	'UserLanguage_Language_bi' => 'bislama',
	'UserLanguage_Language_bm' => 'bambarčina',
	'UserLanguage_Language_bn' => 'bengálčina',
	'UserLanguage_Language_bo' => 'tibetčina',
	'UserLanguage_Language_br' => 'bretónčina',
	'UserLanguage_Language_bs' => 'bosniačtina',
	'UserLanguage_Language_ca' => 'katalánčina',
	'UserLanguage_Language_ce' => 'čečenčina',
	'UserLanguage_Language_ch' => 'čamorčina',
	'UserLanguage_Language_co' => 'korzičtina',
	'UserLanguage_Language_cr' => 'krí',
	'UserLanguage_Language_cs' => 'čeština',
	'UserLanguage_Language_cu' => 'cirkevná slovančina',
	'UserLanguage_Language_cv' => 'čuvaština',
	'UserLanguage_Language_cy' => 'waleština',
	'UserLanguage_Language_da' => 'dánčina',
	'UserLanguage_Language_de' => 'nemčina',
	'UserLanguage_Language_dv' => 'divehi',
	'UserLanguage_Language_dz' => 'dzongkä',
	'UserLanguage_Language_ee' => 'eweština',
	'UserLanguage_Language_el' => 'gréčtina',
	'UserLanguage_Language_en' => 'angličtina',
	'UserLanguage_Language_eo' => 'esperanto',
	'UserLanguage_Language_es' => 'španielčina',
	'UserLanguage_Language_et' => 'estónčina',
	'UserLanguage_Language_eu' => 'baskičtina',
	'UserLanguage_Language_fa' => 'perzština',
	'UserLanguage_Language_ff' => 'fulbčina',
	'UserLanguage_Language_fi' => 'fínčina',
	'UserLanguage_Language_fj' => 'fidžijčina',
	'UserLanguage_Language_fo' => 'faerčina',
	'UserLanguage_Language_fr' => 'francúzština',
	'UserLanguage_Language_fy' => 'západná frízština',
	'UserLanguage_Language_ga' => 'írčina',
	'UserLanguage_Language_gd' => 'škótčina',
	'UserLanguage_Language_gl' => 'galícijčina',
	'UserLanguage_Language_gn' => 'guaraní',
	'UserLanguage_Language_gu' => 'gudžarátčina',
	'UserLanguage_Language_gv' => 'mančina',
	'UserLanguage_Language_ha' => 'hauština',
	'UserLanguage_Language_he' => 'hebrejčina',
	'UserLanguage_Language_hi' => 'hindčina',
	'UserLanguage_Language_ho' => 'hiri motu',
	'UserLanguage_Language_hr' => 'chorvátčina',
	'UserLanguage_Language_ht' => 'haitský',
	'UserLanguage_Language_hu' => 'maďarčina',
	'UserLanguage_Language_hy' => 'arménčina',
	'UserLanguage_Language_hz' => 'herero',
	'UserLanguage_Language_ia' => 'interlingua',
	'UserLanguage_Language_id' => 'indonézština',
	'UserLanguage_Language_ie' => 'interlingue',
	'UserLanguage_Language_ig' => 'igboština',
	'UserLanguage_Language_is' => 'islandčina',
	'UserLanguage_Language_it' => 'taliančina',
	'UserLanguage_Language_ja' => 'japončina',
	'UserLanguage_Language_jv' => 'jávčina',
	'UserLanguage_Language_ka' => 'gruzínčina',
	'UserLanguage_Language_kg' => 'konžština',
	'UserLanguage_Language_kj' => 'kuaňama',
	'UserLanguage_Language_kk' => 'kazaština',
	'UserLanguage_Language_kl' => 'grónska eskimáčtina',
	'UserLanguage_Language_km' => 'kambodžská khmérčina',
	'UserLanguage_Language_kn' => 'kannadčina',
	'UserLanguage_Language_ko' => 'kórejčina',
	'UserLanguage_Language_kr' => 'kanurijčina',
	'UserLanguage_Language_ks' => 'kašmírčina',
	'UserLanguage_Language_ku' => 'kurdčina',
	'UserLanguage_Language_kv' => 'komijčina',
	'UserLanguage_Language_kw' => 'kornčina',
	'UserLanguage_Language_ky' => 'kirgizština',
	'UserLanguage_Language_la' => 'latinčina',
	'UserLanguage_Language_lb' => 'luxemburčina',
	'UserLanguage_Language_lg' => 'gandčina',
	'UserLanguage_Language_ln' => 'lingalčina',
	'UserLanguage_Language_lo' => 'laoština',
	'UserLanguage_Language_lt' => 'litovčina',
	'UserLanguage_Language_lu' => 'luba-katanga',
	'UserLanguage_Language_lv' => 'lotyština',
	'UserLanguage_Language_mg' => 'malgaština',
	'UserLanguage_Language_mh' => 'kajin-majol',
	'UserLanguage_Language_mi' => 'maorijčina',
	'UserLanguage_Language_mk' => 'macedónčina',
	'UserLanguage_Language_ml' => 'malajálamčina',
	'UserLanguage_Language_mn' => 'mongolčina',
	'UserLanguage_Language_mr' => 'maráthčina',
	'UserLanguage_Language_ms' => 'malajčina',
	'UserLanguage_Language_mt' => 'maltčina',
	'UserLanguage_Language_my' => 'barmčina',
	'UserLanguage_Language_na' => 'nauru',
	'UserLanguage_Language_nb' => 'bokmål',
	'UserLanguage_Language_ne' => 'nepálčina',
	'UserLanguage_Language_ng' => 'ndonga',
	'UserLanguage_Language_nl' => 'holandčina',
	'UserLanguage_Language_nn' => 'nórsky nynorsk',
	'UserLanguage_Language_no' => 'nórčina',
	'UserLanguage_Language_nv' => 'navajo',
	'UserLanguage_Language_ny' => 'čewa',
	'UserLanguage_Language_oc' => 'okcitánčina',
	'UserLanguage_Language_oj' => 'odžibva',
	'UserLanguage_Language_om' => 'oromčina',
	'UserLanguage_Language_or' => 'uríjčina',
	'UserLanguage_Language_os' => 'osetčina',
	'UserLanguage_Language_pa' => 'pandžábčina',
	'UserLanguage_Language_pi' => 'pálí',
	'UserLanguage_Language_pl' => 'poľština',
	'UserLanguage_Language_ps' => 'paštúnčina',
	'UserLanguage_Language_pt' => 'portugalčina',
	'UserLanguage_Language_qu' => 'kečuánčina',
	'UserLanguage_Language_rm' => 'rétorománčina',
	'UserLanguage_Language_rn' => 'rundčina',
	'UserLanguage_Language_ro' => 'rumunčina',
	'UserLanguage_Language_ru' => 'ruština',
	'UserLanguage_Language_rw' => 'rwandčina',
	'UserLanguage_Language_sa' => 'sanskrit',
	'UserLanguage_Language_sc' => 'sardínčina',
	'UserLanguage_Language_sd' => 'sindhčina',
	'UserLanguage_Language_sg' => 'sango',
	'UserLanguage_Language_si' => 'sinhalčina',
	'UserLanguage_Language_sk' => 'slovenčina',
	'UserLanguage_Language_sl' => 'slovinčina',
	'UserLanguage_Language_sm' => 'samojčina',
	'UserLanguage_Language_sn' => 'šončina',
	'UserLanguage_Language_so' => 'somálčina',
	'UserLanguage_Language_sq' => 'albánčina',
	'UserLanguage_Language_sr' => 'srbčina',
	'UserLanguage_Language_ss' => 'svazijčina',
	'UserLanguage_Language_st' => 'južná sothčina',
	'UserLanguage_Language_su' => 'sundčina',
	'UserLanguage_Language_sv' => 'švédčina',
	'UserLanguage_Language_sw' => 'swahilčina',
	'UserLanguage_Language_ta' => 'tamilčina',
	'UserLanguage_Language_te' => 'telugčina',
	'UserLanguage_Language_tg' => 'tadžičtina',
	'UserLanguage_Language_th' => 'thajčina',
	'UserLanguage_Language_ti' => 'tigrejčina',
	'UserLanguage_Language_tk' => 'turkménčina',
	'UserLanguage_Language_tl' => 'tagalčina',
	'UserLanguage_Language_tn' => 'tswančina',
	'UserLanguage_Language_to' => 'tonžtina',
	'UserLanguage_Language_tr' => 'turečtina',
	'UserLanguage_Language_ts' => 'tsonga',
	'UserLanguage_Language_tt' => 'tatárčina',
	'UserLanguage_Language_tw' => 'twi',
	'UserLanguage_Language_ty' => 'tahitčina',
	'UserLanguage_Language_ug' => 'ujgurčina',
	'UserLanguage_Language_uk' => 'ukrajinčina',
	'UserLanguage_Language_ur' => 'urdčina',
	'UserLanguage_Language_uz' => 'uzbečtina',
	'UserLanguage_Language_ve' => 'vendčina',
	'UserLanguage_Language_vi' => 'vietnamčina',
	'UserLanguage_Language_vo' => 'volapük',
	'UserLanguage_Language_wa' => 'valónčina',
	'UserLanguage_Language_wo' => 'wolof',
	'UserLanguage_Language_xh' => 'xhosa',
	'UserLanguage_Language_yi' => 'jidiš',
	'UserLanguage_Language_yo' => 'jorubčina',
	'UserLanguage_Language_za' => 'čuangčina',
	'UserLanguage_Language_zh' => 'čínština',
	'UserLanguage_Language_zu' => 'zuluština',
);
